@@ -15,7 +15,8 @@ J_LOG_ERROR         =8,   /*Other runtime errors or unexpected conditions */
 J_LOG_WARN          =16,  /*'Almost' errors, other runtime situations that are undesirable or unexpected */
 J_LOG_USER_ACTION   =32,  /* Everything user is doing.*/
 J_LOG_NETWORK       =64,  /*Networking info, e.g. new connection establishments, game starting etc. */
-J_LOG_NETWORK_DEBUG =128  /* Networking debug */
+J_LOG_NETWORK_DEBUG =128,  /* Networking debug */
+J_LOG_MENTOR_SPEECH =256  /* All what mentor tries to speak */
 };
 
 void cem_add_to_log(char *message,int type);
