@@ -28,9 +28,9 @@
 #include "singinggame.h"
 #include "composition_game.h"
 #include "file_helper.h"
-#include "chum.h" //for chum_states
-
+#include "chum.h"
 
+#include "../../cem/cem.h"
 
 
 /*
@@ -75,7 +75,9 @@ static gboolean cupboard_composition_icon_clicked(TangleButton *tanglebutton, gp
 	
 	gchar *filename; 
 	filename = g_strdup_printf("%s",(gchar*)data);
-	printf("filename '%s'\n",filename);
+	gchar* message = g_strdup_printf("Filename for loading '%s'",filename);
+	cem_add_to_log(message,J_LOG_DEBUG);
+	g_free(message);
 
 	strtok(filename, "+"); //this first is directory path. No use in here.
 
@@ -121,7 +123,7 @@ static gchar* icon_filename_from_json(char* filename){
   GError *error = NULL;
   if (!json_parser_load_from_file (parser, filename, &error))
         {
-          //g_print ("Error: %s\n", error->message);
+          //cem_add_to_log(error->message,J_LOG_ERROR);
           g_error_free (error);
           g_object_unref (parser);
           return NULL;
@@ -165,7 +167,7 @@ static void value_from_json(char* filename, char** path, char** record, char** l
   GError *error = NULL;
   if (!json_parser_load_from_file (parser, filename, &error))
         {
-          //g_print ("Error: %s\n", error->message);
+          //cem_add_to_log(error->message,J_LOG_ERROR);
           g_error_free (error);
           g_object_unref (parser);
           return;
@@ -216,7 +218,7 @@ This checks and loads icons from disk.
 This is called each time cupboard is shown.
 */
 static gboolean load_icons_from_disk (gpointer data){
-	printf("cupboard: load_icons_from_disk\n");
+	cem_add_to_log("cupboard: load_icons_from_disk",J_LOG_DEBUG);
 	//When ending composing started from cupboard, we come back to this function.
 	//Set easy/advanced state back to what it was before loading compositions.
 
@@ -420,7 +422,7 @@ static gboolean load_icons_from_disk (gpointer data){
 
 //This is callback for json.
 void cupboard_start_cupboard(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
-	printf("cupboard_start_cupboard\n");
+	cem_add_to_log("cupboard_start_cupboard",J_LOG_DEBUG);
 	jammo_mentor_set_idle_speech(jammo_mentor_get_default(), ""); //If it takes too long to load
 	ClutterActor* hourglass = jammo_get_actor_by_id("wait");
 	clutter_actor_show(hourglass);
@@ -429,7 +431,7 @@ void cupboard_start_cupboard(TangleAction *action, GObject *source, const gchar
 
 //This is callback for json.
 void cupboard_door_clicked(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
-	printf("cupboard_door_clicked\n");
+	cem_add_to_log("cupboard_door_clicked",J_LOG_USER_ACTION);
 	jammo_mentor_shut_up(jammo_mentor_get_default());
 	ClutterActor* actor;
 	ClutterActor* actor2;
