@@ -28,7 +28,6 @@
 #include "singinggame.h"
 #include "file_helper.h"
 #include "chum.h"
-#include "gui.h"
 
 static ClutterActor* recording_cursor; //we want ask this location
 
@@ -83,7 +82,8 @@ static void start_sequencer(JammoMentor* mentor, const gchar* speech, gboolean i
 
 static void song_view_showed(ClutterTimeline* t, gpointer sequencer){
 	clutter_actor_hide(jammo_get_actor_by_id("songselection-mask"));
-	printf("song_view_showed\n");
+	cem_add_to_log("song_view_showed",J_LOG_INFO);
+
 	jammo_song* song = chum_get_current_song();
 	jammo_mentor_set_idle_speech(jammo_mentor_get_default(), "");
 
@@ -104,23 +104,23 @@ static void song_view_showed(ClutterTimeline* t, gpointer sequencer){
 	//If song doesn't have "name_XX.spx" look for "intro_XX.spx"
 	gchar *filepath1;
 	filepath1 =  g_strdup_printf("%s/name%s.spx", song->fullpath, chum_get_selected_language());
-	printf("song.c: looking for name_XX:'%s'\n",filepath1);
+	//printf("song.c: looking for name_XX:'%s'\n",filepath1);
 	fd_name = open(filepath1,O_RDONLY);
 	g_free(filepath1);
 
 	if (fd_name == -1) {  //nameXX File not found
 		filepath1 =  g_strdup_printf("%s/intro%s.spx", song->fullpath, chum_get_selected_language());
-		printf("song.c: looking for intro_XX:'%s'\n",filepath1);
+		//printf("song.c: looking for intro_XX:'%s'\n",filepath1);
 		fd_intro = open(filepath1,O_RDONLY);
 		if (fd_intro == -1) { //intro_XX File not found
 			//No name_XX nor intro_XX, say: "start after prelude"
-			printf("not founded name_XX or intro_XX\n");
+			//printf("not founded name_XX or intro_XX\n");
 			mentor_tells = g_strdup_printf("songstartC.spx %s",
                 vocal_on_language?"":"no_vocal_on_this_song.spx"
                 );
 		}
 		else  { //say only intro_XX
-			printf("intro_XX founded (but not name_XX)\n");
+			//printf("intro_XX founded (but not name_XX)\n");
 			mentor_tells = g_strdup_printf("%s", filepath1);
 		}
 		g_free(filepath1);
@@ -209,7 +209,7 @@ static void remove_mask_after_animation(ClutterTimeline* t, gpointer mask){
 
 
 static void on_sequencer_stopped_from_cupboard(JammoSequencer* sequencer_old, gpointer none) {
-	printf("Sequencer '%p' stopped from cupboard\n", sequencer_old);
+	cem_add_to_log("Cupboard-Sequencer stopped",J_LOG_INFO);
 	//Hide all
 	ClutterActor*	mainview = jammo_get_actor_by_id("main-views-widget");
 	clutter_container_foreach(CLUTTER_CONTAINER(mainview), CLUTTER_CALLBACK(tangle_actor_hide_animated), NULL);
@@ -232,16 +232,16 @@ This function is used on singing game and cupboard.
 */
 static gboolean song_icon_clicked(TangleButton* tanglebutton, gpointer data){
 	clutter_actor_show(jammo_get_actor_by_id("songselection-mask"));
-	printf("Song icon clicked\n");
+	cem_add_to_log("Song icon clicked",J_LOG_USER_ACTION);
 	ClutterActor* view;
 	if ((view = tangle_view_new())) {
 		ClutterActor* mainview;
 		if ((mainview = jammo_get_actor_by_id("main-views-widget"))){
-			printf("Will add 'view' to 'mainview'\n");	
+			//printf("Will add 'view' to 'mainview'\n");
 			clutter_container_add(CLUTTER_CONTAINER(mainview), view, NULL);
 			g_object_set(view, "transition-duration", 0,NULL);
 			clutter_actor_show(view);
-			printf("succesfully made new view and put it to mainview\n");
+			//printf("succesfully made new view and put it to mainview\n");
 		}
 	}
 
@@ -261,7 +261,7 @@ static gboolean song_icon_clicked(TangleButton* tanglebutton, gpointer data){
 
 	gchar* image_filename;
 	image_filename = g_strdup_printf("%s/background.png",path);
-	printf("image_filename = '%s'\n",image_filename);
+	//printf("image_filename = '%s'\n",image_filename);
 
 	ClutterActor *texture = clutter_texture_new_from_file(image_filename, NULL);
 	if (!texture) {
@@ -350,7 +350,7 @@ static gboolean song_icon_clicked(TangleButton* tanglebutton, gpointer data){
 		}
 
 		JammoBackingTrack* backing_track;
-		printf("looking file '%s' for backing_track \n",filename);
+		//printf("looking file '%s' for backing_track \n",filename);
 		backing_track = jammo_backing_track_new(filename);   //for comping track
 		jammo_sequencer_add_track(sequencer, JAMMO_TRACK(backing_track));
 		g_free(filename);
@@ -373,7 +373,9 @@ static gboolean song_icon_clicked(TangleButton* tanglebutton, gpointer data){
 			filepath1 = g_strdup_printf("%s/cursor.png", song->fullpath ); //try without language postfix
 			int fd = open(filepath1,O_RDONLY);
 			if (fd == -1) {
-				printf("file '%s' not found, using default cursor\n",filepath1);
+				gchar* message = g_strdup_printf("file '%s' not found, using default cursor",filepath1);
+				cem_add_to_log(message,J_LOG_WARN);
+				g_free(message);
 				//contour_cursor = config_get_configured_actor(NULL,"contour_star");
 			} else {
 				clutter_texture_set_from_file (CLUTTER_TEXTURE (contour_cursor), filepath1, NULL);
@@ -416,7 +418,6 @@ static gboolean song_icon_clicked(TangleButton* tanglebutton, gpointer data){
 
 		jammo_sequencer_add_track(sequencer, JAMMO_TRACK(recording_track));
 
-		chum_set_state_of_chum(SCREEN_SONG_RECORDING);
 
 		g_signal_connect(timeline, "completed", G_CALLBACK(song_view_showed), sequencer);
 
@@ -437,7 +438,7 @@ static gboolean song_icon_clicked(TangleButton* tanglebutton, gpointer data){
 			g_free(filename);
 			filename = g_strdup_printf("%s/comping.ogg", song->fullpath); //try without language postfix
 			}
-		printf("looking for file '%s' for comping_track\n",filename);
+		//printf("looking for file '%s' for comping_track\n",filename);
 
 		JammoBackingTrack* backing_track;
 		backing_track = jammo_backing_track_new(filename);   //for comping track
@@ -446,14 +447,13 @@ static gboolean song_icon_clicked(TangleButton* tanglebutton, gpointer data){
 
 		gchar *loaded_filename;
 		loaded_filename = g_strdup_printf("%s",song->name_of_recorded);
-		printf("looking for file '%s' for loaded_track\n",loaded_filename);
+		//printf("looking for file '%s' for loaded_track\n",loaded_filename);
 
 		JammoBackingTrack* backing_track2;
 		backing_track2 = jammo_backing_track_new(loaded_filename);
 		jammo_sequencer_add_track(sequencer, JAMMO_TRACK(backing_track2));
 		g_free(loaded_filename);
 
-		chum_set_state_of_chum(SCREEN_FROM_CUPBOARD);
 
 		g_signal_connect(sequencer, "stopped", G_CALLBACK(on_sequencer_stopped_from_cupboard),view);
 		g_signal_connect(timeline, "completed", G_CALLBACK(start_sequencer_after_animation), sequencer);
@@ -566,7 +566,7 @@ void song_prepare_icon(jammo_song* song){
 This is for song selection menu
 */
 GList* song_init_songs_from_disk(){
-	printf("loading songs from disk\n");
+	cem_add_to_log("song_init: loading songs from disk",J_LOG_DEBUG);
 	GList* songs = NULL;
 
 	//On easy mode, load only songs from 'easy' folder
@@ -596,7 +596,7 @@ GList* song_init_songs_from_disk(){
 			base_path=g_strdup_printf("%s/.jammo/songs/",home);
 			}
 
-		printf("base_path='%s'\n",base_path);
+		//printf("base_path='%s'\n",base_path);
 		////////////////////
 
 
@@ -619,7 +619,7 @@ GList* song_init_songs_from_disk(){
 			}
 		//Next folder
 		}
-	printf("loading from disk done\n");
+	cem_add_to_log("song_init: loading from disk done",J_LOG_DEBUG);
 return songs;
 }
 
