@@ -17,6 +17,7 @@
 #include "composition_game_file_helper.h"
 #include "../../meam/jammo-backing-track.h"
 
+#include "../../cem/cem.h"
 static int x_place_for_icon = 0; //Used when making icons for save-menu
 
 
@@ -77,7 +78,9 @@ static gboolean save_image_pressed(TangleButton *tanglebutton, gpointer data){
 	clutter_actor_hide(jammo_get_actor_by_id("saving_dialog_cancel")); //No canceling after image is selected.
 
 	const gchar* name_of_icon = clutter_actor_get_name(CLUTTER_ACTOR(tanglebutton));
-	printf("Selected '%s'\n",name_of_icon);
+	gchar* message = g_strdup_printf("Selected '%s' for icon\n",name_of_icon);
+	cem_add_to_log(message,J_LOG_DEBUG);
+	g_free(message);
 
 	gchar* filename_for_saving = g_strdup_printf("+%s+%d+%s-",theme->name,theme->variation,chum_is_easy_game()?"e":"a");
 	//e.g.: +fantasy+2+e-
@@ -361,7 +364,7 @@ static void on_sequencer_stopped(JammoSequencer* sequencer, gpointer data) {
 		return;
 		}
 
-	printf("Sequencer stopped\n");
+	cem_add_to_log("Sequencer stopped",J_LOG_USER_ACTION);
 	tangle_actor_show(TANGLE_ACTOR(jammo_mentor_get_default()));
 
 	//Check is any soundfamily visible and start it's animations
@@ -758,8 +761,9 @@ if (use_two_tracks) y_offset=80;
 	clutter_actor_set_size(container_for_backingtrack_blocks,number_of_slots*WIDTH_OF_SLOT, 38.0);
 	clutter_actor_set_size(container_for_tracks,number_of_slots*WIDTH_OF_SLOT, 120.0+y_offset); //track is 80 and backingtrack is 40
 
-
-	printf("tempo_factory (time_sig): %d, beats_per_minute: %d\n",tempo_factory,beats_per_minute);
+	gchar* message = g_strdup_printf("tempo_factory (time_sig): %d, beats_per_minute: %d",tempo_factory,beats_per_minute);
+	cem_add_to_log(message,J_LOG_DEBUG);
+	g_free(message);
 
 	//We want operate whole time with guint64.
 	guint64 temp=60*tempo_factory;
@@ -775,7 +779,9 @@ if (use_two_tracks) y_offset=80;
 	gchar* filename_with_path;
 	filename_with_path = tangle_lookup_filename(backing_track_filepath);
 
-	printf("backingtrack filename (with fullpath): '%s'\n",filename_with_path);
+	message = g_strdup_printf("backingtrack filename (with fullpath): '%s'",filename_with_path);
+	cem_add_to_log(message,J_LOG_DEBUG);
+	g_free(message);
 	int fd = open(filename_with_path,O_RDONLY);
 	if (fd != -1) { //Found it.
 		JammoBackingTrack* backing_track = jammo_backing_track_new(filename_with_path);
@@ -806,12 +812,12 @@ if (use_two_tracks) y_offset=80;
 
 	//pair-game:
 	if (chum_get_pair_composition()) {
-		printf("pairgame\n");
+		cem_add_to_log("pairgame",J_LOG_DEBUG);
 		jammo_editing_track_view_set_editing_enabled(JAMMO_EDITING_TRACK_VIEW(track_view2),FALSE);
 		g_object_set(chum_get_pair_composition(),"peer-track-view", track_view2,NULL); //this will handle all other things
 	}
 	else {
-		printf("single player game\n");
+		cem_add_to_log("single player game", J_LOG_DEBUG);
 		g_object_set(track_view2, "disabled-slots-begin", disabled_slots_for_begin, "disabled-slots-end", disabled_slots_for_end,NULL);
 		clutter_actor_set_reactive(track_view2, TRUE);
 	}
@@ -856,7 +862,7 @@ if (use_two_tracks) y_offset=80;
 }
 
 void delete_theme(jammo_theme* theme){
-	printf("**DELETING THEME**\n");
+	cem_add_to_log("Freeing theme",J_LOG_DEBUG);
 
 	if (theme->animation_timelines != NULL) {
 		remove_all_icon_animations(theme);
