@@ -20,6 +20,8 @@
 #include "composition_game.h"
 #include "theme.h"
 
+#include "../../cem/cem.h"
+
 /*
 This function is called when user chooses and clicks one theme in theme_selection (defined on themeselection-view.json).
 Selected theme is 'name'-property of clicked button.
@@ -29,7 +31,9 @@ void themeselection_theme_clicked(TangleAction *action, GObject *source, const g
 	
 	//subthemes are 1,2,3.
 	int variation = (rand () % 3) + 1;
-	printf("Random variation is '%d'\n",variation);
+	gchar* message = g_strdup_printf("Random variation is '%d'\n",variation);
+	cem_add_to_log(message,J_LOG_INFO);
+	g_free(message);
 	
 	jammo_theme* theme = composition_game_start_theme(name,variation,jammo_get_actor_by_id("themeselection-view"));
 
@@ -58,7 +62,7 @@ void themeselection_theme_clicked(TangleAction *action, GObject *source, const g
 
 
 static gboolean join_selected_game(TangleButton* tanglebutton, gpointer data){
-	printf("join_selected_game pressed\n");
+	cem_add_to_log("join_selected_game pressed",J_LOG_USER_ACTION);
 	//set this to client and join game
 	gems_group_info * group = (gems_group_info*)data;
 	guint id = group->id;
@@ -81,7 +85,7 @@ static gboolean join_selected_game(TangleButton* tanglebutton, gpointer data){
 
 
 void themeselection_going_to (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
-printf("composing game clicked\n");
+cem_add_to_log("Selected composing game (starting theme-selection)",J_LOG_USER_ACTION);
 //If advanced game level, check if there are another jammo-players
 if (!chum_is_easy_game()) {
 	//check if there are another jammo running (or another peerhood?)
@@ -146,7 +150,10 @@ if (!chum_is_easy_game()) {
 				avatar_icon=tangle_button_new_with_background_actor(clutter_texture_new_from_file("/opt/jammo/themes/city/110/beatbox.png", NULL)); //TODO: use avatar
 				g_object_set(avatar_icon, "x", 100.0,  "y", 100.0 *(counter+1), NULL);
 				guint * group_id = &(((gems_group_info*)(g_list_nth(pair_game_list, counter)->data))->id );
-				printf("pair game: counter %d, pair games %d, group_id %u\n", counter, number_of_pair_games, *group_id);
+				gchar* message = g_strdup_printf("pair game: counter %d, pair games %d, group_id %u\n", counter, number_of_pair_games, *group_id);
+				cem_add_to_log(message,J_LOG_NETWORK);
+				g_free(message);
+
 				// give group as parameter for callback
 				g_signal_connect (avatar_icon, "clicked", G_CALLBACK (join_selected_game),(gems_group_info*)(g_list_nth(pair_game_list, counter)->data));
 				tangle_widget_add(TANGLE_WIDGET(container), avatar_icon, NULL);
@@ -154,7 +161,10 @@ if (!chum_is_easy_game()) {
 
 
 				gchar* theme_icon_name = g_strdup_printf("/opt/jammo/%s_icon.png", theme_name);
-				printf("theme_icon_name: '%s'\n",theme_icon_name);
+				message = g_strdup_printf("theme_icon_name: '%s'",theme_icon_name);
+				cem_add_to_log(message,J_LOG_NETWORK);
+				g_free(message);
+
 				theme_icon=tangle_button_new_with_background_actor(clutter_texture_new_from_file(theme_icon_name, NULL));
 				g_free(theme_icon_name);
 				g_object_set(theme_icon, "x", 200.0,  "y", 100.0 *(counter+1), "width", 400.0, "height", 80.0, NULL);
@@ -178,7 +188,7 @@ tangle_action_execute(TANGLE_ACTION(jammo_get_object_by_id("main-menu-composing-
 
 
 void themeselection_create_game(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
-	printf("create game\n");
+	cem_add_to_log("create game",J_LOG_NETWORK);
 	tangle_action_execute(TANGLE_ACTION(jammo_get_object_by_id("main-menu-composing-action")));
 
 	//Now there are marker on theme_selection that pair game is selected
