@@ -30,6 +30,8 @@ static gboolean melodic_selected = FALSE;
 
 static gchar* last_played_filename=NULL;
 static gchar* image_name_for_last_played=NULL;
+static GList* visible_borders = NULL; //Actors for frames surrounding selected image
+
 
 static JammoSequencer* adhoc_sequencer=NULL;
 static void on_sequencer_stopped(JammoSequencer* sequencer, gpointer user_data) {
@@ -39,9 +41,30 @@ static void on_sequencer_stopped(JammoSequencer* sequencer, gpointer user_data)
 }
 
 
+
+static void show_and_add_to_list(ClutterActor* actor, gpointer none) {
+	//printf("show borders and add them to list\n");
+	clutter_actor_show(actor);
+	visible_borders=g_list_append(visible_borders,actor);
+}
+
+static void clear_list_and_make_new(){
+	if (visible_borders){
+		g_list_foreach(visible_borders, (GFunc)clutter_actor_hide,NULL);
+		g_list_free(visible_borders);
+	}
+
+	visible_borders = NULL; //make new
+}
+
 void backingtrack_song_clicked (TangleButton* tanglebutton, gpointer none){
 	const gchar* name = clutter_actor_get_name(CLUTTER_ACTOR(tanglebutton));
 	printf("backingtrack_song_clicked: '%s'\n",name);
+	//Remove and add frames for selected.
+	clear_list_and_make_new(); //for visible_borders
+	ClutterActor* actor = tangle_button_get_normal_background_actor(tanglebutton);
+	clutter_container_foreach(CLUTTER_CONTAINER(actor), CLUTTER_CALLBACK(show_and_add_to_list), NULL);
+
 	JammoSequencer* global_sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
 
 	//Vocal or accompaniment only
@@ -60,6 +83,8 @@ void backingtrack_song_clicked (TangleButton* tanglebutton, gpointer none){
 			postfix=""; //It has all tempo-variations. It doesn't have postfix for language
 		else if (strcmp(name,"SiyaHamba")==0)   //This is exception
 			postfix=""; //It has all tempo-variations. It doesn't have postfix for language
+		else if (strcmp(name,"banana")==0)   //This is exception
+			postfix=""; //It has all tempo-variations. It doesn't have postfix for language
 		else if ( (strcmp(name,"ScarboroughFairGrime")==0) ||     //This is exception
               (strcmp(name,"ScarboroughFairFolkMetal")==0) ||
               (strcmp(name,"ScarFairSouthAsian")==0) )
@@ -74,7 +99,7 @@ void backingtrack_song_clicked (TangleButton* tanglebutton, gpointer none){
 	else
 		prefix ="Sa";
 
-	gchar* backing_track_filename = g_strdup_printf("%s/backingtracks/%s_%s_$t_$p%s.ogg",DATA_DIR,prefix,name,postfix);
+	gchar* backing_track_filename = g_strdup_printf("%s/backingtracks/%s_%s_$t_$p%s.ogg",AUDIO_DIR,prefix,name,postfix);
 	printf ("looking backing_track_filename: '%s'\n",backing_track_filename);
 	if (adhoc_sequencer){
 		jammo_sequencer_stop(adhoc_sequencer);
@@ -207,7 +232,13 @@ printf("backingtrack_down_arrow_clicked\n");
 
 //Set clamping after view is visible. It does not harm when called second time.
 void backingtrack_selection_show_completed(TangleAction *tangleaction, GObject *source, const gchar *trigger, TangleProperties *properties){
-	ClutterAction* action = tangle_actor_get_action_by_type(jammo_get_actor_by_id("backingtrack-selection-container"), TANGLE_TYPE_SCROLL_ACTION);
-	g_signal_connect_swapped(action, "clamp-offset-y", G_CALLBACK(tangle_widget_clamp_child_boundaries), jammo_get_actor_by_id("backingtrack-selection-container"));
+	clear_list_and_make_new(); //for visible_borders
+	ClutterActor* actor = jammo_get_actor_by_id("backingtrack-selection-container");
+	if (actor) {
+		ClutterAction* action = tangle_actor_get_action_by_type(actor, TANGLE_TYPE_SCROLL_ACTION);
+		if (action)
+			g_signal_connect_swapped(action, "clamp-offset-y", G_CALLBACK(tangle_widget_clamp_child_boundaries), actor);
+	}
+
 }
 
