@@ -106,46 +106,25 @@ Will return NULL in error cases.
 Returns new just created sample, not actual sample from wheel.
 */
 static JammoSample* get_centermost_sample_from_loop_roll(ClutterActor* wheel) {
-	gfloat y;
-	gfloat offset=0,not_used; //How much scroller is scrolled
-	gfloat height;    //Height of the scroller (we take this from color_box behind samples)
+	JammoSample* sample = NULL;
+	gfloat offset;
+	ClutterActorBox box;
 
-	ClutterAction* scroll_action = tangle_actor_get_action_by_type(wheel,TANGLE_TYPE_SCROLL_ACTION);
-	tangle_scroll_action_get_offsets(TANGLE_SCROLL_ACTION(scroll_action), &not_used,&offset);
-
-	//Check height of first sample-button, suppose all have same height
-	ClutterActor* first_actor = tangle_widget_get_nth_child(TANGLE_WIDGET(wheel),0);
-	//If first is NULL, suppose they are all NULL.
-	if (first_actor==NULL)
-		return NULL;
-	offset+= clutter_actor_get_height(first_actor);
-
-	//Check height of the wheel
-	height = clutter_actor_get_height(wheel);
-	//printf("height = %f\n",height);
-
-	//Check all sample button which one is closest to center (='offset')
-	float best_value = height;
-	JammoSampleButton* closest = NULL;
+	offset = clutter_actor_get_height(wheel) / 2.0;
+	printf("offset = %f\n",offset);
 
 	GList* children;
 	for (children = tangle_widget_get_children_readonly(TANGLE_WIDGET(wheel)); children; children = children->next) {
-		if (!JAMMO_IS_SAMPLE_BUTTON(children->data)){
-			//printf("this is not sample_button\n");  //Color_box triggers this at least
-			continue;
+		if (JAMMO_IS_SAMPLE_BUTTON(children->data)){
+			clutter_actor_get_allocation_box(CLUTTER_ACTOR(children->data), &box);
+			if (box.y1 < offset && box.y2 > offset) {
+				sample = jammo_sample_new_from_existing(jammo_sample_button_get_sample(JAMMO_SAMPLE_BUTTON(children->data)));
+				break;
+			}
 		}
-
-		y = clutter_actor_get_y (children->data);
-		if (y==0) y+=height; //actor in first slot should be consider be in after very last (+height)
-
-		if (ABS_F(y-offset) < best_value) {
-			best_value = ABS_F(y-offset);
-			closest = JAMMO_SAMPLE_BUTTON(children->data);
-		}
-
 	}
-	if (closest==NULL) return NULL;
-	return jammo_sample_new_from_existing(jammo_sample_button_get_sample(closest));
+
+	return sample;
 }
 
 
