@@ -8,8 +8,7 @@ This is part of the sequencer.
 #ifndef SEQUENCER_LOOP_H_
 #define SEQUENCER_LOOP_H_
 
-#include "../jammo-game-task.h"
-void sequencer_loop_tune_wheels(JammoGameTask* task);
+void sequencer_loop_tune_wheels(int level_number);
 ClutterActor* sequencer_loop_give_sample_button_for_this_id(guint id);
 
 #endif /* SEQUENCER_LOOP_H_ */
