@@ -97,13 +97,18 @@ gboolean pressed_sequencer_button_track_label (TangleButton *tanglebutton, gpoin
 		}
 	}
 	else if  (JAMMO_IS_EDITING_TRACK_VIEW(track_view)){
-			printf(" it is editing_track (start jammer)\n");
-			tangle_actor_hide_animated(TANGLE_ACTOR(jammo_mentor_get_default()));
-			clutter_actor_show(jammo_get_actor_by_id("jammer-view"));
-			clutter_actor_hide(jammo_get_actor_by_id("fullsequencer-view"));
-			start_jammer();
+			printf(" it is editing_track\n");
+			const gchar* name = clutter_actor_get_name(CLUTTER_ACTOR(track_view));
+			if (name && strcmp(name,"jammer")==0)
+				{
+				printf("  named jammer -> start_jammer\n");
+				tangle_actor_hide_animated(TANGLE_ACTOR(jammo_mentor_get_default()));
+				clutter_actor_show(jammo_get_actor_by_id("jammer-view"));
+				clutter_actor_hide(jammo_get_actor_by_id("fullsequencer-view"));
+				start_jammer();}
+			else
+				printf("  Do nothing!\n");
 		}
-
 	return TRUE;
 }
 
@@ -281,21 +286,22 @@ Functions for json
 
 void fullsequencer_play_clicked (TangleButton* tanglebutton, gpointer none){
 	printf("fullsequencer: Play-Stop-Button pressed\n");
-
-	//tanglebutton is toggle-button.
-	gboolean selected;
-	g_object_get(tanglebutton, "selected", &selected,  NULL);
-
-	JammoSequencer* sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
-	if (selected) {
-		jammo_sequencer_play(sequencer);
-	}
-	else {
-		jammo_sequencer_stop(sequencer);
-	}
+	//Button is (tangle-)binded to sequencer, so there are nothing to do.
 }
 
 
+/*
+Play-button is made by template. When it is taken in use, this function is called.
+*/
+void fullsequencer_play_loaded (TangleButton* tanglebutton, gpointer none){
+	//printf("fullsequencer: Play-Stop-Button LOADED\n");
+	g_signal_handlers_disconnect_by_func(tanglebutton, fullsequencer_play_loaded, NULL);
+	JammoSequencer* sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
+
+ TangleBinding* binding;
+ binding = tangle_binding_new(G_OBJECT(tanglebutton), "selected", G_OBJECT(sequencer), "play");
+}
+
 
 //TODO
 void fullsequencer_record_clicked (TangleButton* tanglebutton, gpointer none){
