@@ -182,17 +182,22 @@ static gint rpc_callback(const gchar* interface, const gchar* method, GArray* ar
  */
 static void create_directories(void) {
 	gchar* cmd;
+	gchar* message;
 
 	gchar* compositions_directory = configure_get_compositions_directory();
 	cmd= g_strdup_printf("mkdir -p %s",compositions_directory);
 	if (system(cmd)) {
-		printf("Error, can't call '%s'\n", cmd);
+		message = g_strdup_printf("Can't call '%s' ", cmd);
+		cem_add_to_log(message, J_LOG_ERROR);
+		g_free(message);
 	}
 	g_free(cmd);
 
 	cmd= g_strdup_printf("mkdir -p %s/7-12",compositions_directory); //Compositions for 7-12 game
 	if (system(cmd)) {
-		printf("Error, can't call '%s'\n", cmd);
+		message = g_strdup_printf("Can't call '%s' ", cmd);
+		cem_add_to_log(message, J_LOG_ERROR);
+		g_free(message);;
 	}
 	g_free(cmd);
 
@@ -201,13 +206,17 @@ static void create_directories(void) {
 
 	cmd = g_strdup_printf("mkdir -p %s",singings_directory);
 	if (system(cmd)) {
-		printf("Error, can't call '%s'\n", cmd);
+		message = g_strdup_printf("Can't call '%s' ", cmd);
+		cem_add_to_log(message, J_LOG_ERROR);
+		g_free(message);
 	}
 	g_free(cmd);
 	
 	cmd = g_strdup_printf("mkdir -p %s/wavs",singings_directory);
 	if (system(cmd)) {
-		printf("Error, can't call '%s'\n", cmd);
+		message = g_strdup_printf("Can't call '%s' ", cmd);
+		cem_add_to_log(message, J_LOG_ERROR);
+		g_free(message);;
 	}
 	g_free(cmd);
 
@@ -219,7 +228,15 @@ int main(int argc, char** argv) {
 	osso_context_t* osso_context;
 #endif
 
-	cem_set_log_level(J_LOG_DEBUG +J_LOG_INFO +J_LOG_FATAL +J_LOG_ERROR +J_LOG_WARN  +J_LOG_USER_ACTION +J_LOG_NETWORK +J_LOG_NETWORK_DEBUG);
+	cem_set_log_level(J_LOG_DEBUG
+		+J_LOG_INFO
+		+J_LOG_FATAL
+		+J_LOG_ERROR
+		+J_LOG_WARN
+		+J_LOG_USER_ACTION
+		+J_LOG_NETWORK
+		+J_LOG_NETWORK_DEBUG
+		+J_LOG_MENTOR_SPEECH);
 
 	gchar* message = g_strdup_printf("JamMo-%s started",VERSION);
 	cem_add_to_log(message, J_LOG_INFO);
@@ -251,7 +268,7 @@ int main(int argc, char** argv) {
 	GRand* grand = g_rand_new_with_seed(time(NULL));
 	jammo_gems_init(argc, argv);
 	gems_profile_manager_login(g_rand_int(grand),NULL,NULL);
-	printf("Selected random ID = %u\n",gems_profile_manager_get_userid(NULL));
+	//printf("Selected random ID = %u\n",gems_profile_manager_get_userid(NULL));
 	g_rand_free(grand);
 	
 	gems_enable_network_timeout_functions();
@@ -285,10 +302,12 @@ int main(int argc, char** argv) {
 
 	create_directories();
 
+
 	/* TODO: Temporary: make sure Mentor classes exists. */
-	printf("%ld %ld %ld\n", (long)JAMMO_TYPE_MENTOR, (long)JAMMO_TYPE_MENTOR_ACTION, (long)JAMMO_TYPE_TRACK_VIEW);
-	/* Orientation games related */
-	printf("%ld %ld %ld\n",  (long)JAMMO_TYPE_GAME_TASK,  (long)JAMMO_TYPE_GAME_LEVEL,  (long)JAMMO_TYPE_GAME_LEVEL_VIEW);
+	/* And orientation games related */
+	message = g_strdup_printf("%ld %ld %ld %ld %ld %ld", (long)JAMMO_TYPE_MENTOR, (long)JAMMO_TYPE_MENTOR_ACTION, (long)JAMMO_TYPE_TRACK_VIEW,  (long)JAMMO_TYPE_GAME_TASK,  (long)JAMMO_TYPE_GAME_LEVEL,  (long)JAMMO_TYPE_GAME_LEVEL_VIEW);
+	cem_add_to_log(message, J_LOG_NONE); //This doesn't do anything.
+	g_free(message);
 
 	if ((stylesheet = get_jammo_stylesheet())) {
 		tangle_stylesheet_set_default(stylesheet);
@@ -349,7 +368,9 @@ int main(int argc, char** argv) {
 	clutter_actor_hide(CLUTTER_ACTOR(jammo_mentor_get_default()));
 
 	gchar* lang = getenv ("LANG");
-	printf("LANG='%s'\n",lang);
+	message = g_strdup_printf("getenv(LANG)='%s'",lang);
+	cem_add_to_log(message, J_LOG_DEBUG);
+	g_free(message);
 
 	gchar* lang2=g_strndup (lang,5); //omit charset.
 	gchar* path;
@@ -358,19 +379,22 @@ int main(int argc, char** argv) {
 	else
 		path = g_strdup_printf("mentor_speech/%s/mentor",lang2); //TODO: one 'useless' mentor-folder
 
-	printf("language path='%s'\n",path);
+	message = g_strdup_printf("mentor language path='%s' ",path);
+	cem_add_to_log(message, J_LOG_DEBUG);
+	g_free(message);
+
 	jammo_mentor_set_language(jammo_mentor_get_default(),path);
 	g_free(path);
 
 
 	if (!strcmp(application_name,"jammo3_6")) { //start jammo 3-6 years
-		printf("Starting 3-6 years game\n");
+		cem_add_to_log("Will start 3-6 years game", J_LOG_DEBUG);
 		g_timeout_add(10, start_3_6_game,NULL);
 		g_timeout_add(10000, door_timeouts,NULL); //10 seconds and door will be opened automatically
 	}
 
 	else if (!strcmp(application_name,"jammo7_12")) { //start jammo 7-12 years
-		printf("Starting 7-12 years game\n");
+		cem_add_to_log("Will start 7-12 years game", J_LOG_DEBUG);
 	}
 
 	//These are only debug shortcuts:
@@ -418,7 +442,7 @@ int main(int argc, char** argv) {
 	return 0;
 }
 static gboolean door_timeouts(gpointer data){
-printf("door_timeouts\n");
+//printf("door_timeouts\n");
 welcome_door_clicked(NULL,NULL,NULL,NULL);
 return FALSE;
 }
