@@ -41,6 +41,7 @@ enum {
 	PROP_TEMPO,
 	PROP_PITCH,
 	PROP_OUTPUT_FILENAME,
+	PROP_PLAY,
 	PROP_TIME_SIGNATURE_BEATS,
 	PROP_TIME_SIGNATURE_NOTE_VALUE
 };
@@ -242,7 +243,8 @@ void jammo_sequencer_set_time_signature(JammoSequencer * sequencer, guint time_s
 			track = JAMMO_TRACK(list->data);
 			JAMMO_TRACK_GET_CLASS(track)->set_time_signature(track, time_signature_beats, time_signature_note_value);
 		}
-		g_object_notify(G_OBJECT(sequencer), "time-signature");
+		g_object_notify(G_OBJECT(sequencer), "time-signature-beats");
+		g_object_notify(G_OBJECT(sequencer), "time-signature-note-value");
 	}
 }
 
@@ -257,6 +259,7 @@ void jammo_sequencer_play(JammoSequencer* sequencer) {
 		start_playing(sequencer);
 	}
 	sequencer->priv->playing = TRUE;
+	g_object_notify(G_OBJECT(sequencer), "play");
 }
 
 /**
@@ -270,6 +273,7 @@ void jammo_sequencer_stop(JammoSequencer* sequencer) {
 	gst_element_set_state(sequencer->priv->pipeline, GST_STATE_NULL);
 	g_signal_emit(sequencer, signals[STOPPED], 0);
 	sequencer->priv->playing = FALSE;
+	g_object_notify(G_OBJECT(sequencer), "play");
 }
 
 /**
@@ -284,6 +288,7 @@ void jammo_sequencer_pause(JammoSequencer* sequencer) {
 	gst_element_set_state(sequencer->priv->pipeline, GST_STATE_PAUSED);
 	g_signal_emit(sequencer, signals[PAUSED], 0);
 	sequencer->priv->playing = FALSE;
+	g_object_notify(G_OBJECT(sequencer), "play");
 }
 
 /**
@@ -514,6 +519,13 @@ static void jammo_sequencer_set_property(GObject* object, guint prop_id, const G
 		case PROP_OUTPUT_FILENAME:
 			jammo_sequencer_set_output_filename(sequencer, g_value_get_string(value));
 			break;
+		case PROP_PLAY:
+			if (g_value_get_boolean(value)) {
+				jammo_sequencer_play(sequencer);
+			} else {
+				jammo_sequencer_stop(sequencer);
+			}
+			break;
 		case PROP_TIME_SIGNATURE_BEATS:
 			jammo_sequencer_set_time_signature(sequencer, g_value_get_uint(value), sequencer->priv->time_signature_note_value);
 			break;
@@ -544,6 +556,9 @@ static void jammo_sequencer_get_property(GObject* object, guint prop_id, GValue*
 		case PROP_OUTPUT_FILENAME:
 			g_value_set_string(value, sequencer->priv->output_filename);
 			break;
+		case PROP_PLAY:
+			g_value_set_boolean(value, sequencer->priv->playing);
+			break;
 		case PROP_TIME_SIGNATURE_BEATS:
 			g_value_set_uint(value, sequencer->priv->time_signature_beats);
 			break;
@@ -659,6 +674,20 @@ static void jammo_sequencer_class_init(JammoSequencerClass* klass) {
 	                                NULL,
 	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
 
+	/**
+	 * JammoSequencer:play:
+	 *
+	 * This can be used for play/stop the sequencer. And it can be used to ask current playing-state of sequencer.
+	 * TRUE=plaing/start_play
+	 * FALSE=stopped/stop_play
+	 */
+	g_object_class_install_property(gobject_class, PROP_PLAY,
+	                                g_param_spec_boolean("play",
+	                                "Play or stop sequencer",
+	                                "Play or stop sequencer",
+	                                FALSE,
+	                                G_PARAM_READABLE | G_PARAM_WRITABLE |G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
+
 	/**
 	 * JammoSequencer::started:
 	 * @sequencer: the object which received the signal
@@ -801,6 +830,8 @@ static gboolean on_bus_message(GstBus* bus, GstMessage* message, gpointer data)
 		case GST_MESSAGE_EOS:
 			gst_element_set_state(sequencer->priv->pipeline, GST_STATE_NULL);
 			g_signal_emit(sequencer, signals[STOPPED], 0);
+			sequencer->priv->playing=FALSE;
+			g_object_notify(G_OBJECT(sequencer), "play");
 			break;
 		case GST_MESSAGE_ERROR:
 			gst_message_parse_error(message, &error, &debug);
